@@ -1,9 +1,8 @@
-use crate::options::{flags, OptionsError, NumberSource};
 use crate::options::parser::MatchedFlags;
 use crate::options::vars::{self, Vars};
+use crate::options::{flags, NumberSource, OptionsError};
 
-use crate::output::file_name::{Options, Classify, ShowIcons, EmbedHyperlinks};
-
+use crate::output::file_name::{Classify, EmbedHyperlinks, Options, ShowIcons};
 
 impl Options {
     pub fn deduce<V: Vars>(matches: &MatchedFlags<'_>, vars: &V) -> Result<Self, OptionsError> {
@@ -11,7 +10,11 @@ impl Options {
         let show_icons = ShowIcons::deduce(matches, vars)?;
         let embed_hyperlinks = EmbedHyperlinks::deduce(matches)?;
 
-        Ok(Self { classify, show_icons, embed_hyperlinks })
+        Ok(Self {
+            classify,
+            show_icons,
+            embed_hyperlinks,
+        })
     }
 }
 
@@ -19,8 +22,11 @@ impl Classify {
     fn deduce(matches: &MatchedFlags<'_>) -> Result<Self, OptionsError> {
         let flagged = matches.has(&flags::CLASSIFY)?;
 
-        if flagged { Ok(Self::AddFileIndicators) }
-              else { Ok(Self::JustFilenames) }
+        if flagged {
+            Ok(Self::AddFileIndicators)
+        } else {
+            Ok(Self::JustFilenames)
+        }
     }
 }
 
@@ -28,19 +34,21 @@ impl ShowIcons {
     pub fn deduce<V: Vars>(matches: &MatchedFlags<'_>, vars: &V) -> Result<Self, OptionsError> {
         if matches.has(&flags::NO_ICONS)? || !matches.has(&flags::ICONS)? {
             Ok(Self::Off)
-        }
-        else if let Some(columns) = vars.get(vars::EXA_ICON_SPACING).and_then(|s| s.into_string().ok()) {
+        } else if let Some(columns) = vars
+            .get_with_fallback(vars::EZA_ICON_SPACING, vars::EXA_ICON_SPACING)
+            .and_then(|s| s.into_string().ok())
+        {
             match columns.parse() {
-                Ok(width) => {
-                    Ok(Self::On(width))
-                }
+                Ok(width) => Ok(Self::On(width)),
                 Err(e) => {
-                    let source = NumberSource::Env(vars::EXA_ICON_SPACING);
+                    let source = NumberSource::Env(
+                        vars.source(vars::EZA_ICON_SPACING, vars::EXA_ICON_SPACING)
+                            .unwrap(),
+                    );
                     Err(OptionsError::FailedParse(columns, source, e))
                 }
             }
-        }
-        else {
+        } else {
             Ok(Self::On(1))
         }
     }
@@ -50,7 +58,10 @@ impl EmbedHyperlinks {
     fn deduce(matches: &MatchedFlags<'_>) -> Result<Self, OptionsError> {
         let flagged = matches.has(&flags::HYPERLINK)?;
 
-        if flagged { Ok(Self::On) }
-              else { Ok(Self::Off) }
+        if flagged {
+            Ok(Self::On)
+        } else {
+            Ok(Self::Off)
+        }
     }
 }
