@@ -4,7 +4,6 @@ use crate::fs::feature::xattr;
 use crate::options::flags;
 use crate::options::parser::MatchedFlags;
 
-
 static USAGE_PART1: &str = "Usage:
   eza [options] [files...]
 
@@ -35,6 +34,7 @@ FILTERING AND SORTING OPTIONS
   -s, --sort SORT_FIELD      which field to sort by
   --group-directories-first  list directories before other files
   -D, --only-dirs            list only directories
+  -f, --only-files           list only files
   -I, --ignore-glob GLOBS    glob patterns (pipe-separated) of files to ignore";
 
 static GIT_FILTER_HELP: &str = "  \
@@ -71,9 +71,9 @@ static GIT_VIEW_HELP:   &str = "  \
   --git                    list each file's Git status, if tracked or ignored
   --no-git                 suppress Git status (always overrides --git, --git-repos, --git-repos-no-status)
   --git-repos              list root of git-tree status";
-static EXTENDED_HELP:   &str = "  \
+static EXTENDED_HELP: &str = "  \
   -@, --extended           list each file's extended attributes and sizes";
-static SECATTR_HELP:    &str = "  \
+static SECATTR_HELP: &str = "  \
   -Z, --context            list each file's security context";
 
 /// All the information needed to display the help text, which depends
@@ -83,7 +83,6 @@ static SECATTR_HELP:    &str = "  \
 pub struct HelpString;
 
 impl HelpString {
-
     /// Determines how to show help, if at all, based on the user’s
     /// command-line arguments. This one works backwards from the other
     /// ‘deduce’ functions, returning Err if help needs to be shown.
@@ -94,15 +93,13 @@ impl HelpString {
     pub fn deduce(matches: &MatchedFlags<'_>) -> Option<Self> {
         if matches.count(&flags::HELP) > 0 {
             Some(Self)
-        }
-        else {
+        } else {
             None
         }
     }
 }
 
 impl fmt::Display for HelpString {
-
     /// Format this help options into an actual string of help
     /// text to be displayed to the user.
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
@@ -127,7 +124,6 @@ impl fmt::Display for HelpString {
     }
 }
 
-
 #[cfg(test)]
 mod test {
     use crate::options::{Options, OptionsResult};
@@ -135,14 +131,14 @@ mod test {
 
     #[test]
     fn help() {
-        let args = vec![ OsStr::new("--help") ];
+        let args = vec![OsStr::new("--help")];
         let opts = Options::parse(args, &None);
         assert!(matches!(opts, OptionsResult::Help(_)));
     }
 
     #[test]
     fn help_with_file() {
-        let args = vec![ OsStr::new("--help"), OsStr::new("me") ];
+        let args = vec![OsStr::new("--help"), OsStr::new("me")];
         let opts = Options::parse(args, &None);
         assert!(matches!(opts, OptionsResult::Help(_)));
     }
@@ -151,6 +147,6 @@ mod test {
     fn unhelpful() {
         let args = vec![];
         let opts = Options::parse(args, &None);
-        assert!(! matches!(opts, OptionsResult::Help(_)))  // no help when --help isn’t passed
+        assert!(!matches!(opts, OptionsResult::Help(_))) // no help when --help isn’t passed
     }
 }
