@@ -1,4 +1,4 @@
-pub use self::cell::{TextCell, TextCellContents, DisplayWidth};
+pub use self::cell::{DisplayWidth, TextCell, TextCellContents};
 pub use self::escape::escape;
 
 pub mod details;
@@ -15,7 +15,6 @@ mod cell;
 mod escape;
 mod tree;
 
-
 /// The **view** contains all information about how to format output.
 #[derive(Debug)]
 pub struct View {
@@ -25,7 +24,6 @@ pub struct View {
     pub deref_links: bool,
 }
 
-
 /// The **mode** is the “type” of output.
 #[derive(PartialEq, Eq, Debug)]
 #[allow(clippy::large_enum_variant)]
@@ -36,11 +34,9 @@ pub enum Mode {
     Lines,
 }
 
-
 /// The width of the terminal requested by the user.
 #[derive(PartialEq, Eq, Debug, Copy, Clone)]
 pub enum TerminalWidth {
-
     /// The user requested this specific number of columns.
     Set(usize),
 
@@ -54,9 +50,10 @@ impl TerminalWidth {
         // terminal, but we’re only interested in stdout because it’s
         // where the output goes.
 
-        match self {
+        #[rustfmt::skip]
+        return match self {
             Self::Set(width)  => Some(width),
             Self::Automatic   => terminal_size::terminal_size().map(|(w, _)| w.0.into()),
-        }
+        };
     }
 }
