@@ -1,16 +1,26 @@
 use ansiterm::Style;
-use uzers::{Users, Groups};
+use uzers::{Groups, Users};
 
 use crate::fs::fields as f;
 use crate::output::cell::TextCell;
 use crate::output::table::UserFormat;
 
-pub trait Render{
-    fn render<C: Colours, U: Users+Groups>(self, colours: &C, users: &U, format: UserFormat) -> TextCell;
+pub trait Render {
+    fn render<C: Colours, U: Users + Groups>(
+        self,
+        colours: &C,
+        users: &U,
+        format: UserFormat,
+    ) -> TextCell;
 }
 
 impl Render for Option<f::Group> {
-    fn render<C: Colours, U: Users+Groups>(self, colours: &C, users: &U, format: UserFormat) -> TextCell {
+    fn render<C: Colours, U: Users + Groups>(
+        self,
+        colours: &C,
+        users: &U,
+        format: UserFormat,
+    ) -> TextCell {
         use uzers::os::unix::GroupExt;
 
         let mut style = colours.not_yours();
@@ -18,17 +28,15 @@ impl Render for Option<f::Group> {
         let group = match self {
             Some(g) => match users.get_group_by_gid(g.0) {
                 Some(g) => (*g).clone(),
-                None    => return TextCell::paint(style, g.0.to_string()),
+                None => return TextCell::paint(style, g.0.to_string()),
             },
             None => return TextCell::blank(colours.no_group()),
         };
 
-
         let current_uid = users.get_current_uid();
         if let Some(current_user) = users.get_user_by_uid(current_uid) {
-
             if current_user.primary_group_id() == group.gid()
-            || group.members().iter().any(|u| u == current_user.name())
+                || group.members().iter().any(|u| u == current_user.name())
             {
                 style = colours.yours();
             }
@@ -43,14 +51,12 @@ impl Render for Option<f::Group> {
     }
 }
 
-
 pub trait Colours {
     fn yours(&self) -> Style;
     fn not_yours(&self) -> Style;
     fn no_group(&self) -> Style;
 }
 
-
 #[cfg(test)]
 #[allow(unused_results)]
 pub mod test {
@@ -59,22 +65,21 @@ pub mod test {
     use crate::output::cell::TextCell;
     use crate::output::table::UserFormat;
 
-    use uzers::{User, Group};
-    use uzers::mock::MockUsers;
-    use uzers::os::unix::GroupExt;
     use ansiterm::Colour::*;
     use ansiterm::Style;
-
+    use uzers::mock::MockUsers;
+    use uzers::os::unix::GroupExt;
+    use uzers::{Group, User};
 
     struct TestColours;
 
+    #[rustfmt::skip]
     impl Colours for TestColours {
         fn yours(&self)     -> Style { Fixed(80).normal() }
         fn not_yours(&self) -> Style { Fixed(81).normal() }
         fn no_group(&self)   -> Style { Black.italic() }
     }
 
-
     #[test]
     fn named() {
         let mut users = MockUsers::with_current_uid(1000);
@@ -82,21 +87,32 @@ pub mod test {
 
         let group = Some(f::Group(100));
         let expected = TextCell::paint_str(Fixed(81).normal(), "folk");
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Name));
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Name)
+        );
 
         let expected = TextCell::paint_str(Fixed(81).normal(), "100");
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Numeric));
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Numeric)
+        );
     }
 
-
     #[test]
     fn unnamed() {
         let users = MockUsers::with_current_uid(1000);
 
         let group = Some(f::Group(100));
         let expected = TextCell::paint_str(Fixed(81).normal(), "100");
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Name));
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Numeric));
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Name)
+        );
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Numeric)
+        );
     }
 
     #[test]
@@ -107,7 +123,10 @@ pub mod test {
 
         let group = Some(f::Group(100));
         let expected = TextCell::paint_str(Fixed(80).normal(), "folk");
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Name))
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Name)
+        )
     }
 
     #[test]
@@ -120,13 +139,23 @@ pub mod test {
 
         let group = Some(f::Group(100));
         let expected = TextCell::paint_str(Fixed(80).normal(), "folk");
-        assert_eq!(expected, group.render(&TestColours, &users, UserFormat::Name))
+        assert_eq!(
+            expected,
+            group.render(&TestColours, &users, UserFormat::Name)
+        )
     }
 
     #[test]
     fn overflow() {
         let group = Some(f::Group(2_147_483_648));
         let expected = TextCell::paint_str(Fixed(81).normal(), "2147483648");
-        assert_eq!(expected, group.render(&TestColours, &MockUsers::with_current_uid(0), UserFormat::Numeric));
+        assert_eq!(
+            expected,
+            group.render(
+                &TestColours,
+                &MockUsers::with_current_uid(0),
+                UserFormat::Numeric
+            )
+        );
     }
 }
