@@ -2,7 +2,7 @@ use ansiterm::Style;
 
 use crate::theme::lsc::Pair;
 
-
+#[rustfmt::skip]
 #[derive(Debug, Default, PartialEq)]
 pub struct UiStyles {
     pub colourful: bool,
@@ -13,6 +13,7 @@ pub struct UiStyles {
     pub users:            Users,
     pub links:            Links,
     pub git:              Git,
+    pub git_repo:         GitRepo,
     pub security_context: SecurityContext,
     pub file_type:        FileType,
 
@@ -21,7 +22,7 @@ pub struct UiStyles {
     pub inode:        Style,          // in
     pub blocks:       Style,          // bl
     pub header:       Style,          // hd
-    pub octal:        Style,
+    pub octal:        Style,          // oc
 
     pub symlink_path:         Style,  // lp
     pub control_char:         Style,  // cc
@@ -29,6 +30,7 @@ pub struct UiStyles {
     pub broken_path_overlay:  Style,  // bO
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct FileKinds {
     pub normal: Style,        // fi
@@ -38,11 +40,12 @@ pub struct FileKinds {
     pub block_device: Style,  // bd
     pub char_device: Style,   // cd
     pub socket: Style,        // so
-    pub special: Style,
+    pub special: Style,       // sp
     pub executable: Style,    // ex
     pub mount_point: Style,   // mp
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct Permissions {
     pub user_read:          Style,  // ur
@@ -64,6 +67,7 @@ pub struct Permissions {
     pub attribute: Style,           // xa
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct Size {
     pub major: Style,        // df
@@ -82,6 +86,7 @@ pub struct Size {
     pub unit_huge: Style,    // sb ut
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct Users {
     pub user_you: Style,           // uu
@@ -90,12 +95,14 @@ pub struct Users {
     pub group_not_yours: Style,    // gn
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct Links {
     pub normal: Style,           // lc
     pub multi_link_file: Style,  // lm
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct Git {
     pub new: Style,         // ga
@@ -104,25 +111,36 @@ pub struct Git {
     pub renamed: Style,     // gv
     pub typechange: Style,  // gt
     pub ignored: Style,     // gi
-    pub conflicted: Style,
+    pub conflicted: Style,  // gc
+}
+
+#[rustfmt::skip]
+#[derive(Clone, Copy, Debug, Default, PartialEq)]
+pub struct GitRepo {
+    pub branch_main: Style,
+    pub branch_other: Style,
+    pub git_clean: Style,
+    pub git_dirty: Style,
 }
 
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct SELinuxContext {
     pub colon: Style,
-    pub user:  Style,
-    pub role:  Style,
-    pub typ:   Style,
-    pub range: Style,
+    pub user: Style,  // Su
+    pub role: Style,  // Sr
+    pub typ: Style,   // St
+    pub range: Style, // Sl
 }
 
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct SecurityContext {
-    pub none:    Style,
+    pub none:    Style, // Sn
     pub selinux: SELinuxContext,
 }
 
 /// Drawing styles based on the type of file (video, image, compressed, etc)
+#[rustfmt::skip]
 #[derive(Clone, Copy, Debug, Default, PartialEq)]
 pub struct FileType {
     pub image: Style,       // im - image file
@@ -143,13 +161,12 @@ impl UiStyles {
     }
 }
 
-
 impl UiStyles {
-
     /// Sets a value on this set of colours using one of the keys understood
     /// by the `LS_COLORS` environment variable. Invalid keys set nothing, but
     /// return false.
     pub fn set_ls(&mut self, pair: &Pair<'_>) -> bool {
+        #[rustfmt::skip]
         match pair.key {
             "di" => self.filekinds.directory    = pair.to_style(),  // DIR
             "ex" => self.filekinds.executable   = pair.to_style(),  // EXEC
@@ -164,84 +181,94 @@ impl UiStyles {
              // Codes we don’t do anything with:
              // MULTIHARDLINK, DOOR, SETUID, SETGID, CAPABILITY,
              // STICKY_OTHER_WRITABLE, OTHER_WRITABLE, STICKY, MISSING
-        }
+        };
         true
     }
 
     /// Sets a value on this set of colours using one of the keys understood
-    /// by the `EXA_COLORS` environment variable. Invalid keys set nothing,
+    /// by the `EZA_COLORS` environment variable. Invalid keys set nothing,
     /// but return false. This doesn’t take the `LS_COLORS` keys into account,
     /// so `set_ls` should have been run first.
     pub fn set_exa(&mut self, pair: &Pair<'_>) -> bool {
+        #[rustfmt::skip]
         match pair.key {
-            "ur" => self.perms.user_read          = pair.to_style(),
-            "uw" => self.perms.user_write         = pair.to_style(),
-            "ux" => self.perms.user_execute_file  = pair.to_style(),
-            "ue" => self.perms.user_execute_other = pair.to_style(),
-            "gr" => self.perms.group_read         = pair.to_style(),
-            "gw" => self.perms.group_write        = pair.to_style(),
-            "gx" => self.perms.group_execute      = pair.to_style(),
-            "tr" => self.perms.other_read         = pair.to_style(),
-            "tw" => self.perms.other_write        = pair.to_style(),
-            "tx" => self.perms.other_execute      = pair.to_style(),
-            "su" => self.perms.special_user_file  = pair.to_style(),
-            "sf" => self.perms.special_other      = pair.to_style(),
-            "xa" => self.perms.attribute          = pair.to_style(),
+            "ur" => self.perms.user_read                = pair.to_style(),
+            "uw" => self.perms.user_write               = pair.to_style(),
+            "ux" => self.perms.user_execute_file        = pair.to_style(),
+            "ue" => self.perms.user_execute_other       = pair.to_style(),
+            "gr" => self.perms.group_read               = pair.to_style(),
+            "gw" => self.perms.group_write              = pair.to_style(),
+            "gx" => self.perms.group_execute            = pair.to_style(),
+            "tr" => self.perms.other_read               = pair.to_style(),
+            "tw" => self.perms.other_write              = pair.to_style(),
+            "tx" => self.perms.other_execute            = pair.to_style(),
+            "su" => self.perms.special_user_file        = pair.to_style(),
+            "sf" => self.perms.special_other            = pair.to_style(),
+            "xa" => self.perms.attribute                = pair.to_style(),
 
             "sn" => self.set_number_style(pair.to_style()),
             "sb" => self.set_unit_style(pair.to_style()),
-            "nb" => self.size.number_byte         = pair.to_style(),
-            "nk" => self.size.number_kilo         = pair.to_style(),
-            "nm" => self.size.number_mega         = pair.to_style(),
-            "ng" => self.size.number_giga         = pair.to_style(),
-            "nt" => self.size.number_huge         = pair.to_style(),
-            "ub" => self.size.unit_byte           = pair.to_style(),
-            "uk" => self.size.unit_kilo           = pair.to_style(),
-            "um" => self.size.unit_mega           = pair.to_style(),
-            "ug" => self.size.unit_giga           = pair.to_style(),
-            "ut" => self.size.unit_huge           = pair.to_style(),
-            "df" => self.size.major               = pair.to_style(),
-            "ds" => self.size.minor               = pair.to_style(),
+            "nb" => self.size.number_byte               = pair.to_style(),
+            "nk" => self.size.number_kilo               = pair.to_style(),
+            "nm" => self.size.number_mega               = pair.to_style(),
+            "ng" => self.size.number_giga               = pair.to_style(),
+            "nt" => self.size.number_huge               = pair.to_style(),
+            "ub" => self.size.unit_byte                 = pair.to_style(),
+            "uk" => self.size.unit_kilo                 = pair.to_style(),
+            "um" => self.size.unit_mega                 = pair.to_style(),
+            "ug" => self.size.unit_giga                 = pair.to_style(),
+            "ut" => self.size.unit_huge                 = pair.to_style(),
+            "df" => self.size.major                     = pair.to_style(),
+            "ds" => self.size.minor                     = pair.to_style(),
 
-            "uu" => self.users.user_you           = pair.to_style(),
-            "un" => self.users.user_someone_else  = pair.to_style(),
-            "gu" => self.users.group_yours        = pair.to_style(),
-            "gn" => self.users.group_not_yours    = pair.to_style(),
+            "uu" => self.users.user_you                 = pair.to_style(),
+            "un" => self.users.user_someone_else        = pair.to_style(),
+            "gu" => self.users.group_yours              = pair.to_style(),
+            "gn" => self.users.group_not_yours          = pair.to_style(),
 
-            "lc" => self.links.normal             = pair.to_style(),
-            "lm" => self.links.multi_link_file    = pair.to_style(),
+            "lc" => self.links.normal                   = pair.to_style(),
+            "lm" => self.links.multi_link_file          = pair.to_style(),
 
-            "ga" => self.git.new                  = pair.to_style(),
-            "gm" => self.git.modified             = pair.to_style(),
-            "gd" => self.git.deleted              = pair.to_style(),
-            "gv" => self.git.renamed              = pair.to_style(),
-            "gt" => self.git.typechange           = pair.to_style(),
-            "gi" => self.git.ignored              = pair.to_style(),
+            "ga" => self.git.new                        = pair.to_style(),
+            "gm" => self.git.modified                   = pair.to_style(),
+            "gd" => self.git.deleted                    = pair.to_style(),
+            "gv" => self.git.renamed                    = pair.to_style(),
+            "gt" => self.git.typechange                 = pair.to_style(),
+            "gi" => self.git.ignored                    = pair.to_style(),
+            "gc" => self.git.conflicted                 = pair.to_style(),
 
-            "xx" => self.punctuation              = pair.to_style(),
-            "da" => self.date                     = pair.to_style(),
-            "in" => self.inode                    = pair.to_style(),
-            "bl" => self.blocks                   = pair.to_style(),
-            "hd" => self.header                   = pair.to_style(),
-            "lp" => self.symlink_path             = pair.to_style(),
-            "cc" => self.control_char             = pair.to_style(),
-            "bO" => self.broken_path_overlay      = pair.to_style(),
+            "xx" => self.punctuation                    = pair.to_style(),
+            "da" => self.date                           = pair.to_style(),
+            "in" => self.inode                          = pair.to_style(),
+            "bl" => self.blocks                         = pair.to_style(),
+            "hd" => self.header                         = pair.to_style(),
+            "oc" => self.octal                          = pair.to_style(),
+            "lp" => self.symlink_path                   = pair.to_style(),
+            "cc" => self.control_char                   = pair.to_style(),
+            "bO" => self.broken_path_overlay            = pair.to_style(),
 
-            "mp" => self.filekinds.mount_point    = pair.to_style(),
+            "mp" => self.filekinds.mount_point          = pair.to_style(),
+            "sp" => self.filekinds.special              = pair.to_style(),  // Catch-all for unrecognized file kind
 
-            "im" => self.file_type.image          = pair.to_style(),
-            "vi" => self.file_type.video          = pair.to_style(),
-            "mu" => self.file_type.music          = pair.to_style(),
-            "lo" => self.file_type.lossless       = pair.to_style(),
-            "cr" => self.file_type.crypto         = pair.to_style(),
-            "do" => self.file_type.document       = pair.to_style(),
-            "co" => self.file_type.compressed     = pair.to_style(),
-            "tm" => self.file_type.temp           = pair.to_style(),
-            "cm" => self.file_type.compiled       = pair.to_style(),
-            "bu" => self.file_type.build          = pair.to_style(),
+            "im" => self.file_type.image                = pair.to_style(),
+            "vi" => self.file_type.video                = pair.to_style(),
+            "mu" => self.file_type.music                = pair.to_style(),
+            "lo" => self.file_type.lossless             = pair.to_style(),
+            "cr" => self.file_type.crypto               = pair.to_style(),
+            "do" => self.file_type.document             = pair.to_style(),
+            "co" => self.file_type.compressed           = pair.to_style(),
+            "tm" => self.file_type.temp                 = pair.to_style(),
+            "cm" => self.file_type.compiled             = pair.to_style(),
+            "bu" => self.file_type.build                = pair.to_style(),
+
+            "Sn" => self.security_context.none          = pair.to_style(),
+            "Su" => self.security_context.selinux.user  = pair.to_style(),
+            "Sr" => self.security_context.selinux.role  = pair.to_style(),
+            "St" => self.security_context.selinux.typ   = pair.to_style(),
+            "Sl" => self.security_context.selinux.range = pair.to_style(),
 
              _   => return false,
-        }
+        };
 
         true
     }
